st-tts 0.1.1

High-level on-device TTS via Supertonic — one-liner synthesize, auto-download models
docs.rs failed to build st-tts-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.